@@ -9,7 +9,7 @@ use Carp;
 use base 'Exporter';
 our @EXPORT = qw(patronize getProxies);
 
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 BEGIN {
     if (defined &CORE::read) {
@@ -29,6 +29,17 @@ BEGIN {
     *CORE::GLOBAL::stat = \&Patro::_stat;
     *CORE::GLOBAL::flock = \&Patro::_flock;
     *CORE::GLOBAL::fcntl = \&Patro::_fcntl;
+
+    *CORE::GLOBAL::sysopen = \&Patro::_sysopen;
+    *CORE::GLOBAL::lstat = \&Patro::_lstat;
+
+    *CORE::GLOBAL::opendir = \&Patro::_opendir;
+    *CORE::GLOBAL::closedir = \&Patro::_closedir;
+    *CORE::GLOBAL::readdir = \&Patro::_readdir;
+    *CORE::GLOBAL::seekdir = \&Patro::_seekdir;
+    *CORE::GLOBAL::telldir = \&Patro::_telldir;
+    *CORE::GLOBAL::rewinddir = \&Patro::_rewinddir;
+    *CORE::GLOBAL::chdir = \&Patro::_chdir;
 }
 
 sub import {
@@ -41,19 +52,6 @@ sub import {
 	    require Patro::Server;
 	    Patro::Server->TEST_MODE;
 
-	    # some tests will check if the remote object has changed
-	    # after being manipulated by the proxy. This can only
-	    # happen with a threaded server (or with certain objects
-	    # that do not maintain state in local memory), so we should
-	    # skip those tests if we are using the forked server.
-	    *ok_threaded = sub {
-		if ($Patro::Server::threads_avail) {
-		    goto &Test::More::ok;
-		} else {
-		    Test::More::ok(1, $_[1] ? "$_[1] - SKIPPED" :
-		       "skip test that requires threaded server");
-		}
-	    };
 	    # a poor man's Data::Dumper, but works for Patro::N objects.
 	    *xjoin = sub {
 		join(",", map { my $r = $_;
@@ -63,7 +61,7 @@ sub import {
 			"{".xjoin(map{"$_:'".$r->{$_}."'"}sort keys %$r)."}" 
 				} : $_ } @_)
 	    };
-	    push @EXPORT, 'ok_threaded', 'xjoin';
+	    push @EXPORT, 'xjoin';
 	}
 	if ($tag eq ':insecure') {
 	    $Patro::SECURE = 0;
@@ -250,6 +248,90 @@ sub _stat {
     }
 }
 
+sub _flock {
+    my ($fh,$op) = @_;
+    if (CORE::ref($fh) eq 'Patro::N5') {
+	return $fh->_tied->__('FLOCK',1,$op);
+    } else {
+	return CORE::flock($fh,$op);
+    }
+}
+
+sub _sysopen {
+    my ($fh,$fname,$mode,$perm) = @_;
+    if (CORE::ref($fh) eq 'Patro::N5') {
+        return $fh->_tied->__('SYSOPEN',1,$fname,$mode,$perm);
+    } elsif (defined ($perm)) {
+        return CORE::sysopen($fh,$fname,$mode,$perm);
+    } else {
+        return CORE::sysopen($fh,$fname,$mode);
+    }
+}
+
+sub _lstat (;*) {
+    my ($fh) = @_;
+    if (CORE::ref($fh) eq 'Patro::N5') {
+	my $context = defined(wantarray) + wantarray + 0;
+	return $fh->_tied->__('LSTAT',$context);
+    }
+    return CORE::lstat $fh;
+}
+
+sub _opendir (*$) {
+    if (CORE::ref($_[0]) eq 'Patro::N5') {
+        return $_[0]->_tied->__('OPENDIR',1,$_[1]);
+    }
+    return CORE::opendir($_[0],$_[1]);
+}
+
+sub _closedir (*) {
+    my ($fh) = @_;
+    if (CORE::ref($fh) eq 'Patro::N5') {
+        return $fh->_tied->__('CLOSEDIR',1);
+    }
+    return CORE::closedir($fh);
+}
+
+sub _readdir (*) {
+    my ($fh) = @_;
+    if (CORE::ref($fh) eq 'Patro::N5') {
+        return $fh->_tied->__('READDIR',undef);
+    }
+    return CORE::readdir($fh);
+}
+
+sub _seekdir (*$) {
+    my ($fh,$pos) = @_;
+    if (CORE::ref($fh) eq 'Patro::N5') {
+        return $fh->_tied->__('SEEKDIR',1,$pos);
+    }
+    return CORE::seekdir($fh,$pos);
+}
+
+sub _telldir (*) {
+    my ($fh) = @_;
+    if (CORE::ref($fh) eq 'Patro::N5') {
+        return $fh->_tied->__('TELLDIR',1);
+    }
+    return CORE::telldir($fh);
+}
+
+sub _rewinddir (*) {
+    my ($fh) = @_;
+    if (CORE::ref($fh) eq 'Patro::N5') {
+        return $fh->_tied->__('REWINDDIR',1);
+    }
+    return CORE::rewinddir($fh);
+}
+
+sub _chdir (;$) {
+    my ($fh) = @_;
+    if ($fh && CORE::ref($fh) eq 'Patro::N5') {
+	return $fh->_tied->__('CHDIR',1);
+    }
+    return CORE::chdir($fh);
+}
+
 1;
 
 =head1 NAME
@@ -259,7 +341,7 @@ Patro - proxy access to remote objects
 
 =head1 VERSION
 
-0.13
+0.14
 
 
 =head1 SYNOPSIS
